4.3 CTXD Results
================

These results are not included in the Language Specification and are
introduced specifically for the CTXD Actuator Profile.

Type: :py:class:`~otupy.core.results.Results` (:py:class:`~otupy.types.base.map.Map`)

.. list-table::
   :widths: 3 4 4 3 40
   :header-rows: 1

   * - ID
     - Name
     - Type
     - #
     - Description
   * - 2
     - services
     - :py:class:`~otupy.types.base.array_of.ArrayOf`\(:py:class:`~otupy.profiles.ctxd.data.service.Service`)
     - 0
     - List all the services.
   * - 2
     - links
     - :py:class:`~otupy.types.base.array_of.ArrayOf`\(:py:class:`~otupy.profiles.ctxd.data.link.Link`)
     - 0
     - List all the links of the services.
   * - 2
     - services_names
     - :py:class:`~otupy.types.base.array_of.ArrayOf`\(:py:class:`~otupy.profiles.ctxd.data.name.Name`)
     - 0
     - List the names of all services. This will likely be removed in future releases.
   * - 2
     - link_names
     - :py:class:`~otupy.types.base.array_of.ArrayOf`\(:py:class:`~otupy.profiles.ctxd.data.name.Name`)
     - 0
     - List the names of all links. This does not work anymore, because Links do not have a name.

Usage requirements:
~~~~~~~~~~~~~~~~~~~

-  The response “services” can only be used when the target is “context”.
-  The response “links” can only be used when the target is “context”.
-  The response “services_names” can only be used when the target is “context”.
-  The response “link_names” can only be used when the target is “context”.
-  service_names/link_names are mutually exclusive with services/links,
   respectively. The choice is based on the value of the “name_only”
   argument in the query.

